**gPhoton** is a project to calibrate, archive, and make available every photon event observed by the GALEX mission in an effort to dramatically improve the flexibility and utility of the data with specific emphasis on enabling short time domain photometric studies.

To get started, please read the [User Guide](https://github.com/cmillion/gPhoton/blob/master/docs/UserGuide.md).  You can also refer to the [Full API](http://gphoton.readthedocs.io/en/master/) available on ReadTheDocs.

Note that Python 2.x is no longer supported by gPhoton, and many things will break under Python 2. **Use Python 3 or above.**

If you use gPhoton software in your research, please cite at least one of the following:
* _Million, et al. "gPhoton: The GALEX Photon Data Archive." The Astrophysical Journal 833.2 (2016): 292._
* _Million, et al., 2016, gPhoton, Astrophysics Source Code Library, record ascl:1603.004_

![Logo](https://travis-ci.org/cmillion/gPhoton.svg?branch=master)
[![Documentation Status](https://readthedocs.org/projects/gphoton/badge/?version=master)](http://gphoton.readthedocs.io/en/master/?badge=master)
<a href="http://ascl.net/1603.004"><img src="https://img.shields.io/badge/ascl-1603.004-blue.svg?colorB=262255" alt="ascl:1603.004" /></a>
